==================================
A handful of utilities for Django!
==================================

.. image:: https://img.shields.io/pypi/v/django-helpful.svg
    :target: https://pypi.python.org/pypi/django-helpful
    :alt: Latest PyPI version
.. image:: https://img.shields.io/pypi/dm/django-helpful.svg
    :target: https://pypi.python.org/pypi/django-helpful
    :alt: Number of PyPI downloads
.. image:: https://img.shields.io/pypi/l/django-helpful.svg
    :target: https://pypi.python.org/pypi/django-helpful


*******
Install
*******

* Copy to helpful or include as git submodule
* Add ```'helpful',``` to ```INSTALLED_APPS ```

